@@ -2,7 +2,6 @@ package Net::Amazon::MechanicalTurk::Command::LoadHITs;
 use strict;
 use warnings;
 use Carp;
-use Data::Dumper;
 use IO::File;
 use Net::Amazon::MechanicalTurk::BulkSupport;
 use Net::Amazon::MechanicalTurk::DataStructure;
@@ -12,7 +11,7 @@ use Net::Amazon::MechanicalTurk::Template;
 use Net::Amazon::MechanicalTurk::Template::ReplacementTemplate;
 use Net::Amazon::MechanicalTurk::DelimitedWriter;
 
-our $VERSION = '1.01_01';
+our $VERSION = '1.00';
 
 =head1 NAME
 
@@ -337,11 +336,11 @@ sub loadHITs {
         if ($mturk->request) {
             $message .= "\nLast operation called " . $mturk->request->{Operation} . ".\n";
             $message .= "\nDump of call parameters:\n" .
-                Dumper($mturk->request, 4) . "\n";
+                formatDataStructure($mturk->request, 4) . "\n";
         }
         if ($mturk->response) {
             $message .= "\nDump of response:\n" .
-                Dumper($mturk->response->fullResult, 4) . "\n";
+                formatDataStructure($mturk->response->fullResult, 4) . "\n";
         }
         Carp::croak($message);
     }
